==> optimizely-oui-46.7.0.tgz: package/module/js/components/DatePicker/CalendarNavButton.js <==
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import Icon from 'react-oui-icons';

var CalendarNavButton = function CalendarNavButton(_ref) {
  var type = _ref.type;
  var title = type === 'previous' ? 'Previous Month' : 'Next Month';
  var style = type === 'previous' ? {
    left: '10px'
  } : {
    right: '10px'
  };
  var icon = type === 'previous' ? React.createElement(Icon, {
    name: "arrow-left"
  }) : React.createElement(Icon, {
    name: "arrow-right"
  });
  return React.createElement("button", {
    title: title,
    style: _objectSpread({
      backgroundColor: '#fff',
      color: '#484848',
      fontSize: 24,
      padding: '5px',
      position: 'absolute',
      top: '15px',
      border: 'none'
    }, style)
  }, icon);
};

CalendarNavButton.propTypes = {
  type: PropTypes.oneOf(['previous', 'next'])
};
export default CalendarNavButton;

==> optimizely-oui-48.14.0.tgz: package/module/js/components/DatePicker/CalendarNavButton.js <==
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from "react";
import PropTypes from "prop-types";
import Icon from "react-oui-icons";

var CalendarNavButton = function CalendarNavButton(_ref) {
  var type = _ref.type;
  var title = type === "previous" ? "Previous Month" : "Next Month";
  var style = type === "previous" ? {
    left: "10px"
  } : {
    right: "10px"
  };
  var icon = type === "previous" ? React.createElement(Icon, {
    name: "arrow-left"
  }) : React.createElement(Icon, {
    name: "arrow-right"
  });
  return React.createElement("button", {
    title: title,
    style: _objectSpread({
      backgroundColor: "#fff",
      color: "#484848",
      fontSize: 24,
      padding: "5px",
      position: "absolute",
      top: "15px",
      border: "none"
    }, style)
  }, icon);
};

CalendarNavButton.propTypes = {
  type: PropTypes.oneOf(["previous", "next"])
};
export default CalendarNavButton;
